rem (c) Copyright IBM Corp. 2005, 2006 All rights reserved.
rem This script is owned by International Business Machines Corporation or
rem one of its subsidiaries ("IBM") and is copyrighted and licensed, not sold.
rem You may copy, modify, and distribute this script in any form without
rem payment to IBM, for any purpose including developing, using, marketing or
rem distributing programs that include or are derivative works of the script.
rem The script provided to you on an "AS IS" basis, without warranty of
rem any kind. IBM HEREBY EXPRESSLY DISCLAIMS ALL WARRANTIES, EITHER
rem EXPRESS OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
rem WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
rem PURPOSE. IBM shall not be liable for indemnification or any damages you suffer 
rem as a result of using, modifying or distributing the script or its derivatives.
rem Each copy of any portion of this script or any derivative work, must
rem include the above copyright notice and disclaimer of warranty.
@echo off
setlocal
cls
echo =========================================================
echo .
echo This script creates the UDDI DB2 database
echo .
echo The script assumes you have:
echo DB2 v8 installed and running
echo .
echo =========================================================
echo .

set DB2UserID=db2admin
set DB2Password=cr0nic

if "%1" NEQ "" ( set DB2UserID=%1 ) ELSE goto ERROREXIT
if "%2" NEQ "" ( set DB2Password=%2 ) ELSE goto ERROREXIT
if "%3" NEQ "" ( set DataBaseName=%3) ELSE goto ERROREXIT
if "%4" NEQ "" ( set SQLPATH=%4) ELSE goto ERROREXIT
if "%5" EQU "x" set ForceSession=Yes
if "%6" NEQ "" goto ERROREXIT

set BufferPoolName=%DataBaseName%TS

echo  DB2UserID: %DB2UserID%
echo  DB2Password: %DB2Password%
echo  DataBaseName: %DataBaseName%
echo  BufferPoolName: %BufferPoolName%
echo  SQLPath: %SQLPATH%
echo .

if not exist "%SQLPATH%\uddi30crt_10_prereq_db2.sql" goto WRONGPATH

rem just to check that we have a db2cmd session
db2 list active databases
if ERRORLEVEL 4 goto NOSESSION

db2set DB2CODEPAGE=1208
if ERRORLEVEL 1 goto ERROREXIT

db2 force application all
if ERRORLEVEL 8 goto NOSESSION
if ERRORLEVEL 1 goto ERROREXIT
ping localhost

db2 db2stop
if %errorlevel% EQU 4 goto RETRY
if ERRORLEVEL 1 goto ERROREXIT
goto START

:RETRY
echo Still some database connections - retrying
db2 list active databases
db2 force application all
ping localhost
db2 db2stop
if %errorlevel% EQU 4 goto RETRY2
if ERRORLEVEL 1 goto ERROREXIT
goto START

:RETRY2
echo STILL some database connections - retying
db2 list active databases
db2 force application all
ping localhost
db2 db2stop
if %errorlevel% EQU 4 goto RETRY3
if ERRORLEVEL 1 goto ERROREXIT
goto START

:RETRY3
echo STILL some database connections - last try
db2 list active databases
db2 force application all
ping localhost
db2 db2stop
if %errorlevel% EQU 4 echo Still some active.  Giving up.
if ERRORLEVEL 1 goto ERROREXIT

:START
db2 db2start
if ERRORLEVEL 1 goto ERROREXIT

db2 drop database %DataBaseName%
if ERRORLEVEL 5 goto ERROREXIT
rem database may not exist so rc = 4

db2 create database %DataBaseName% using codeset UTF-8 territory en
if ERRORLEVEL 1 goto ERROREXIT

db2 connect to %DataBaseName% user %DB2UserID% using %DB2Password%
if ERRORLEVEL 4 goto WRONGUSER
if ERRORLEVEL 1 goto ERROREXIT

db2 update db cfg for %DataBaseName% using applheapsz 2048
if ERRORLEVEL 3 goto ERROREXIT

db2 update db cfg for %DataBaseName% using logfilsiz 8192
if ERRORLEVEL 4 goto ERROREXIT

db2 create bufferpool %BufferPoolName% size 250 pagesize 32K
if ERRORLEVEL 1 goto ERROREXIT

db2 commit
if ERRORLEVEL 1 goto ERROREXIT

db2 flush package cache dynamic
if ERRORLEVEL 1 goto ERROREXIT

db2 create regular tablespace uddits pagesize 32K managed by system using ('%DataBaseName%') extentsize 64 prefetchsize 32 bufferpool %BufferPoolName%
if ERRORLEVEL 1 goto ERROREXIT

db2 create system temporary tablespace TempTableSpacename pagesize 32K managed by system using ('TempTableSpacename') extentsize 32 overhead 14.06 prefetchsize 32 transferrate 0.33 bufferpool %BufferPoolName%
if ERRORLEVEL 1 goto ERROREXIT

db2 terminate
if ERRORLEVEL 1 goto ERROREXIT

db2set DB2CODEPAGE=1208
if ERRORLEVEL 1 goto ERROREXIT

rem NOTE these SQL calls need to be done in this order - they have interdependencies
db2 connect to %DataBaseName% user %DB2UserID% using %DB2Password%
if ERRORLEVEL 1 goto ERROREXIT

db2 -tvf "%SQLPATH%\uddi30crt_10_prereq_db2.sql"
if ERRORLEVEL 1 goto ERROREXIT

db2 -tvf "%SQLPATH%\uddi30crt_20_tables_generic.sql"
if ERRORLEVEL 1 goto ERROREXIT

db2 -tvf "%SQLPATH%\uddi30crt_25_tables_db2udb.sql"
if ERRORLEVEL 1 goto ERROREXIT

db2 -tvf "%SQLPATH%\uddi30crt_30_constraints_generic.sql"
if ERRORLEVEL 1 goto ERROREXIT

db2 -tvf "%SQLPATH%\uddi30crt_35_constraints_db2udb.sql"
if ERRORLEVEL 1 goto ERROREXIT

db2 -tvf "%SQLPATH%\uddi30crt_40_views_generic.sql"
if ERRORLEVEL 1 goto ERROREXIT

db2 -tvf "%SQLPATH%\uddi30crt_45_views_db2udb.sql"
if ERRORLEVEL 1 goto ERROREXIT

db2 -vf "%SQLPATH%\uddi30crt_50_triggers_db2udb.sql"
if ERRORLEVEL 1 goto ERROREXIT

db2 -tvf "%SQLPATH%\uddi30crt_60_insert_initial_static_data.sql"
if ERRORLEVEL 1 goto ERROREXIT

db2 -tvf "%SQLPATH%\uddi30crt_70_insert_default_database_indicator.sql"
if ERRORLEVEL 1 goto ERROREXIT

db2 connect reset
if ERRORLEVEL 1 goto ERROREXIT

db2 terminate
if ERRORLEVEL 1 goto ERROREXIT

echo "================== UDDI DATABASE CREATED SUCCESSFULLY ===================="
if "%ForceSession%" EQU "Yes" exit
goto :EOF

:WRONGPATH
echo .
echo A required file %SQLPATH%\uddi30crt_10_prereq_db2.sql is missing
echo .
echo Make sure you have correctly specifed the path to the SQL files
goto ERROREXIT

:NOSESSION
echo .
echo This batchfile should be run from a db2cmd session
if "%ForceSession%" NEQ "Yes" (
    echo - starting one
    db2cmd /w createUDDI30.bat %DB2UserID% %DB2Password% %DataBaseName% %SQLPATH% x
    goto :EOF
)
echo tried to start one but it did not work
echo .
goto ERROREXIT

:WRONGUSER
echo .
echo you need to use a valid DB2 userid password combination

:ERROREXIT
db2 connect reset
echo .
echo ERROR DETECTED
echo .
echo "USAGE: db2cmd createUDDI30.bat <db2userid> <db2password> <dbName> <path_to_SQL_files>"
echo .
goto :EOF

rem ==================== END OF SCRIPT ==============================================

:EOF